---
title: Collapsible
description: The collapsible component is used to put long sections of information under a block that merchants can expand or collapse.
category: Behavior
keywords:
  - hide
  - show
  - low priority
  - less important
  - disclosure
  - accordion
  - accordian
  - expand content
  - toggle
  - toggleable
  - reveal
  - show more
  - show all button
  - show hide
  - expanding view
  - collapse
examples:
  - fileName: collapsible-default.tsx
    title: Default
    description: Use for a basic “show more” interaction when you need to display more content.
---

## Best practices

The collapsible component should:

- Be used for information that is lower priority or that merchants don’t need to see all the time
- Not be used to hide error messages or other critical information that requires an immediate action

---

## Content guidelines

Collapsible containers are cards with expandable and collapsible functionality, and should follow the content guidelines for [cards](https://polaris.shopify.com/components/card#content-guidelines).

---

## Related components

- To control a collapsible component, use the [button](https://polaris.shopify.com/components/button) component
- To put long sections of information in a container that allows for scrolling, [use the scrollable component](https://polaris.shopify.com/components/scrollable)

---

## Accessibility

Use the collapsible component in conjunction with a [button](https://polaris.shopify.com/components/button). Place the collapsible content immediately after the button that controls it, so merchants with vision or attention issues can easily discover what content is being affected.

- Use the required `id` prop of the collapsible component to give the content a unique `id` value
- Use the `ariaExpanded` prop on the button component to add an `aria-expanded` attribute, which conveys the expanded or collapsed state to screen reader users
- Use the `ariaControls` prop on the button component, and set its value to the `id` value of the collapsible component
