---
title: Merchant-to-customer content
description: Shopify creates content for different audiences. One of those audiences is merchants’ customers. A customer is a person or organization who interacts with a Shopify merchant or a merchant’s sales channel.
icon: EmailNewsletterMajor
keywords:
  - merchant to buyer
  - buyer
  - shopper
  - buyer voice and tone
  - customer voice and tone
  - writing for checkout
  - checkout
  - check out
---

Merchant-to-customer content represents the merchant, not Shopify, and should optimize the customers’ online or retail store experience.

Every UX discipline is encouraged to create content at Shopify. Use this guide when you’re writing content that a customer will see on a Shopify store or receive from a merchant.

You’ll find merchant-to-customer content in places such as:

- Online store checkout pages
- Shipping update emails
- Return labels and emails
- Point of Sale (POS) screens, such as digital receipts and payment errors

---

## What it isn’t

If you write for multiple audiences, it’s important to note that merchant-to-customer content isn’t:

- Shopify-to-buyer content, such as Shopify Pay or Arrive
- Shopify-to-merchant content, such as the Shopify admin
- Shopify-to-world content, such as shopify.com or blog posts

---

## Experience values for customers

Shopify has a set of [experience values](https://polaris.shopify.com/foundations/experience-values). The ones to focus on when creating merchant-to-customer content are:

### Considerate

Wherever and however a customer uses a Shopify experience (even if they don’t know it’s Shopify), we want it to work for them. The best Shopify experiences work on every screen, on every platform, in every language, and in every country.

### Efficient

Shopify experiences help customers achieve goals faster, more accurately, and with less effort. We break complex tasks down into simple steps, use friction to highlight important decisions, and always set expectations about what will happen next.

### Trustworthy

Shopify experiences are genuine, always honest, and transparent. We show customers that merchants act in the customer’s best interest. We create communication that strengthens the trust customers have in merchants.

---

## Merchant voice and tone

Merchant voice and tone is customer-focused.

Shopify merchants sell everything from physical products, such as eco-sneakers, to digital products, like music downloads. The language they use is very different from store to store. This means that when writing from a merchant perspective, we use a voice that’s appropriate on any store, and for any type of customer. Merchant-to-customer content shouldn’t sound out of place coming from any merchant.

### Human, but not individual

Too much personality is inappropriate for some stores. Customers aren’t going through the purchase experience to admire the witty content. Research shows that the majority of people want content that’s easy to understand and communicates concepts efficiently. Not robotic. Not full of personality. Just clear and straightforward to help them complete their task.

Keep in mind that some content, such as emails, can be personalized by merchants. You’re providing a default for them to work from.

<!-- dodont -->

#### Do

- Your payment details couldn’t be verified. Check your card details and try again.
- All transactions are secure and encrypted.
- Select the address that matches your card or payment method.
- Thanks!

  This example is when the customer finishes checkout in person (all other examples are from online checkout).

#### Don’t

- A fatal error occurred.

Whoops! Houston, we have a problem!

- Don’t worry, your details are safe with us!
- Address must correspond with that held by your payment provider.
- Thanks for stopping by! or See you again soon!

<!-- end -->

### Shopping, not ecommerce: use shopper terms

Avoid technical or ecommerce terms. Customers are interested in their order and their delivery, not in inventory and fulfillment. They might want to sign up for news and exclusive offers, but not marketing emails.

<!-- dodont -->

#### Do

- Enter your name exactly as it’s written on your card.
- You’ll get shipping and delivery updates by email.

#### Don’t

- There was a server verification error with your payment provider.
- We’ll inform you when we’ve fulfilled your order.

<!-- end -->

### Concise, but not short

It’s important that any purchase flow is efficient. Use short, easy-to-understand words and phrases. For example:

<!-- dodont -->

#### Do

- Use “to”
- Use “go to”
- There was a problem with our payments

#### Don’t

- Don’t use “in order to”
- Don’t use “proceed to”
- No payment gateway is currently configured

<!-- end -->

But remember that clear beats short. Don’t use content that can be interpreted in different ways. For example, does “bi-weekly” mean twice a week or every two weeks? It’s clearer to say “Every 2 weeks.” Using more words is okay if it provides clarity.

<!-- dodont -->

#### Do

- Every two weeks
- Getting available shipping rates

#### Don’t

- Bi-weekly
- Loading

<!-- end -->

No matter who the audience is, all Shopify content follows the same [grammar and mechanics](https://polaris.shopify.com/content/grammar-and-mechanics) and [product content guidelines](https://polaris.shopify.com/content/product-content).

Read our general [voice and tone guidelines](https://polaris.shopify.com/content/voice-and-tone) to compare how Shopify talks to merchants.

---

## Vocabulary considerations

“Buyer” and “customer” are similar so it’s easy to confuse the use of these terms.

A “buyer” interacts with multiple Shopify stores or has a direct relationship with Shopify, such as through Shopify Pay.

In contrast, a “customer” is a person or organization who interacts with a Shopify merchant or a merchant’s sales channel.

In the Shopify admin and Point-of-Sale (POS), a customer appears on the Customers page when they engage with a merchant in an identifiable way. This could be because they:

- were added or imported by the merchant
- started a purchase but abandoned it at checkout
- made a purchase
- create a customer account
- subscribed to the merchant's mailing list

Word usage to use/avoid:

<!-- dodont -->

#### Do

- Use the store name in place of “merchant”
- Be direct and use “you”
- Focus on the merchant-to-customer relationship
- Use “text message” or “message” when writing for North American audiences
- Use noun + verb phrases for success messages, for example, ”payment sent”
- There was a problem with our payments

#### Don’t

- Merchant (in place of store name)
- Customer or customer (in place of “you”)
- Shopify (keep Shopify out of the conversation)
- SMS
- Oh happy day! (don’t be over-congratulatory)
- Wrong, fail, failure, error (avoid sounding robotic or negative)

<!-- end -->

### Common terms

Use the following terms to refer to common concepts and actions within the merchant-to-customer experience.

Note: all of these terms should be lowercase, unless they're a proper noun or the first word in a sentence.

#### cart

The page that displays an order summary. Customers see this page before they proceed to checkout.

#### checkout

The customer experience for paying for items and completing an order.

#### delivery

How an order reaches the customer. Delivery covers more than just shipping. For example, customers can choose whether the order is shipped to their delivery address or picked up in-store.

#### discount code

A dollar amount, percentage, or code that dictates how much a product will be reduced in price.

#### duties

Additional costs that may be incurred on orders that are delivered internationally. Duties may be incorporated into the shipping cost.

#### gift card

A type of product with monetary value that merchants can either sell to customers or issue to them as a gift, reward, or incentive.

#### item

One unit of a product on an order.

#### login

The credentials that a customer uses to access their account.

#### order

The term for a purchase. Don’t say package, or add unnecessary words like sales order.

#### payment

Describes a specific way a customer can pay such as Visa, MasterCard, or Apple Pay.

#### pay now

This text is displayed on Call To Action (CTA) buttons that trigger a payment. On free orders, this is replaced with “Complete order”.

#### pickup

A delivery option where customers physically collect an order.

#### return

A transaction where a customer sends a product back to the store for an exchange or refund. A refund is part of a return.

#### refund

The funds that a customer receives from a merchant, for example, when returning an item.

#### shipping

How a merchant sends an order to a customer. Also known as the shipping method.

#### subtotal

The cost of the items on an order before additional charges, such as tax and shipping.

#### total

The cost of the items on an order after additional charges such as tax and shipping.

#### you

A way of referring to the customer that's checking out. Use you, or use the name that the customer has provided.

#### we

A way of referring to the store name. Most of the time, refer to the store by name. However, you can use “we” when using the store name would sound overly wordy or insincere.
